//	Advanced System UI
//	Copyright (c) 2011 Brand Huntsman <brand.huntsman@gmail.com>

//////////////////////////////////////////////////////////////////////////

void ui_click_callback( GtkWidget *widget, gpointer data ){
	new_section_vbox("User Interface"); // add setting widgets to section_content_box

	new_checkbox(conf_service_size_unit, "show \"MB\" after service size", NULL);

	new_separator();

	new_message("Orange long tap markers are always displayed");
	new_checkbox(conf_short_tap_markers, "show blue markers for buttons that support short taps", NULL);

	new_separator();

	new_checkbox(conf_start_visible, "show ASUI window at startup", NULL);

	new_separator();

	new_message("When ALS value exceeds the white threshold the white theme is activated and returns to black theme when value drops below the black threshold.");
	new_uint_value(conf_threshold_black, "black threshold [n810 only]", 0, 999999999, NULL);
	new_uint_value(conf_threshold_white, "white threshold [n810 only]", 0, 999999999, NULL);

	new_separator();
}
